==> gap-packages-4.12.0-3-aarch64.pkg.tar.xz: usr/lib/gap/pkg/generalizedmorphismsforcap/README.md <==
<!-- BEGIN HEADER -->
# GeneralizedMorphismsForCAP&ensp;<sup><sup>[![View code][code-img]][code-url]</sup></sup>

### Implementations of generalized morphisms for the CAP project

| Documentation | Latest Release | Build Status of [CAP_project](/../../) | Code Coverage |
| ------------- | -------------- | ------------ | ------------- |
| [![HTML stable documentation][html-img]][html-url] [![PDF stable documentation][pdf-img]][pdf-url] | [![version][version-img]][version-url] [![date][date-img]][date-url] | [![Build Status][tests-img]][tests-url] | [![Code Coverage][codecov-img]][codecov-url] |

<!-- END HEADER -->
<!-- BEGIN FOOTER -->
[html-img]: https://img.shields.io/badge/🔗%20HTML-stable-blue.svg
[html-url]: https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/doc/chap0_mj.html

[pdf-img]: https://img.shields.io/badge/🔗%20PDF-stable-blue.svg
[pdf-url]: https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/download_pdf.html

[version-img]: https://img.shields.io/endpoint?url=https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/badge_version.json&label=🔗%20version&color=yellow
[version-url]: https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/view_release.html

[date-img]: https://img.shields.io/endpoint?url=https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/badge_date.json&label=🔗%20released%20on&color=yellow
[date-url]: https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/view_release.html

[tests-img]: https://github.com/homalg-project/CAP_project/workflows/Tests/badge.svg?branch=master
[tests-url]: https://github.com/homalg-project/CAP_project/actions?query=workflow%3ATests+branch%3Amaster

[codecov-img]: https://codecov.io/gh/homalg-project/CAP_project/branch/master/graph/badge.svg?flag=GeneralizedMorphismsForCAP
[codecov-url]: https://codecov.io/gh/homalg-project/CAP_project/tree/master/GeneralizedMorphismsForCAP

[code-img]: https://img.shields.io/badge/-View%20code-blue?logo=github
[code-url]: https://github.com/homalg-project/CAP_project/tree/master/GeneralizedMorphismsForCAP#top
<!-- END FOOTER -->

==> gap-packages-4.12.2-4-aarch64.pkg.tar.xz: usr/lib/gap/pkg/generalizedmorphismsforcap/README.md <==
<!-- BEGIN HEADER -->
# GeneralizedMorphismsForCAP&ensp;<sup><sup>[![View code][code-img]][code-url]</sup></sup>

### Implementations of generalized morphisms for the CAP project

| Documentation | Latest Release | Build Status of [CAP_project](/../../) | Code Coverage |
| ------------- | -------------- | ------------ | ------------- |
| [![HTML stable documentation][html-img]][html-url] [![PDF stable documentation][pdf-img]][pdf-url] | [![version][version-img]][version-url] [![date][date-img]][date-url] | [![Build Status][tests-img]][tests-url] | [![Code Coverage][codecov-img]][codecov-url] |

<!-- END HEADER -->
<!-- BEGIN FOOTER -->
[html-img]: https://img.shields.io/badge/🔗%20HTML-stable-blue.svg
[html-url]: https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/doc/chap0_mj.html

[pdf-img]: https://img.shields.io/badge/🔗%20PDF-stable-blue.svg
[pdf-url]: https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/download_pdf.html

[version-img]: https://img.shields.io/endpoint?url=https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/badge_version.json&label=🔗%20version&color=yellow
[version-url]: https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/view_release.html

[date-img]: https://img.shields.io/endpoint?url=https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/badge_date.json&label=🔗%20released%20on&color=yellow
[date-url]: https://homalg-project.github.io/CAP_project/GeneralizedMorphismsForCAP/view_release.html

[tests-img]: https://github.com/homalg-project/CAP_project/actions/workflows/Tests.yml/badge.svg?branch=master
[tests-url]: https://github.com/homalg-project/CAP_project/actions/workflows/Tests.yml?query=branch%3Amaster

[codecov-img]: https://codecov.io/gh/homalg-project/CAP_project/branch/master/graph/badge.svg?flag=GeneralizedMorphismsForCAP
[codecov-url]: https://codecov.io/gh/homalg-project/CAP_project/tree/master/GeneralizedMorphismsForCAP

[code-img]: https://img.shields.io/badge/-View%20code-blue?logo=github
[code-url]: https://github.com/homalg-project/CAP_project/tree/master/GeneralizedMorphismsForCAP#top
<!-- END FOOTER -->
